cgexplore.terms.Angle
=====================

.. currentmodule:: cgexplore.terms

.. autoclass:: Angle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Angle.atom_names
      ~Angle.atom_ids
      ~Angle.angle
      ~Angle.angle_k
      ~Angle.atoms
      ~Angle.force
      ~Angle.funct
   
   